
#ifndef NETTLE_MACRO_H_INCLUDED
#define NETTLE_MACRO_H_INCLUDED

#ifdef  __cplusplus
extern "C" {
#endif

/* Reads a 32-bit integer, in network, big-endian, byte order */
#define READ_UINT32(p)  			\
(  (((uint32_t) (p)[0]) << 24)  		\
 | (((uint32_t) (p)[1]) << 16)  		\
 | (((uint32_t) (p)[2]) << 8)   		\
 |  ((uint32_t) (p)[3]))

#define WRITE_UINT32(p, i)			\
{    					\
  (p)[0] = ((i) >> 24) & 0xff;  		\
  (p)[1] = ((i) >> 16) & 0xff;  		\
  (p)[2] = ((i) >> 8) & 0xff;   		\
  (p)[3] = (i) & 0xff;  			\
}

/* And the other, little-endian, byteorder */
#define LE_READ_UINT32(p)			\
(  (((uint32_t) (p)[3]) << 24)  		\
 | (((uint32_t) (p)[2]) << 16)  		\
 | (((uint32_t) (p)[1]) << 8)   		\
 |  ((uint32_t) (p)[0]))

#define LE_WRITE_UINT32(p, i)   		\
{    					\
  (p)[3] = ((i) >> 24) & 0xff;  		\
  (p)[2] = ((i) >> 16) & 0xff;  		\
  (p)[1] = ((i) >> 8) & 0xff;   		\
  (p)[0] = (i) & 0xff;  			\
}

/* Macro to make it easier to loop over several blocks. */
#define FOR_BLOCKS(length, dst, src, blocksize) \
  for (; (length); ((length) -= (blocksize),    \
		  (dst) += (blocksize), 	\
		  (src) += (blocksize)) )

#ifdef  __cplusplus
}
#endif

#endif /* NETTLE_MACRO_H_INCLUDED */

